/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2012 CASSIDIAN, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.model.processing;

import java.net.URI;
import java.util.Date;

import javax.annotation.Generated;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.rdf.Value;

/**
 * WebLab Exchange model used for resources processing v0.4.
 * 
 * This version includes relationships used for WebLab Resources processing.
 * 
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 */
@Generated(value = "org.ow2.weblab.rdf.OWL2Annotator", date = "2012-07-24T13:33:43.488+02:00")
public class WProcessingAnnotator extends BaseAnnotator {


	protected static final String APREFIX = "wlp";


	protected static final URI AURI = URI.create("http://weblab.ow2.org/core/1.2/ontology/processing#");


	protected static final String IS_SYNTHESIS_OF = "isSynthesisOf";


	protected static final String IS_DELIMITER_OF_SUMMARY_UNIT = "isDelimiterOfSummaryUnit";


	protected static final String IS_DELIMITER_OF_TRANSCRIPT_UNIT = "isDelimiterOfTranscriptUnit";


	protected static final String IS_FRAME_OF = "isFrameOf";


	protected static final String IS_DELIMITER_OF_RECOGNITION_UNIT = "isDelimiterOfRecognitionUnit";


	protected static final String IS_DELIMITER_OF_FRAME_UNIT = "isDelimiterOfFrameUnit";


	protected static final String IS_PRODUCED_BY = "isProducedBy";


	protected static final String IS_DELIMITER_OF = "isDelimiterOf";


	protected static final String HAS_BEEN_UPDATED_BY = "hasBeenUpdatedBy";


	protected static final String IS_IN_CLUSTER = "isInCluster";


	protected static final String IS_COMPOSED_BY_CLUSTER = "isComposedByCluster";


	protected static final String IS_IN_CLUSTER_LINK = "isInClusterLink";


	protected static final String REFERS_TO = "refersTo";


	protected static final String HAS_ORIGINAL_FILE_NAME = "hasOriginalFileName";


	protected static final String IS_DELIMITER_OF_SOUNDTRACK_UNIT = "isDelimiterOfSoundtrackUnit";


	protected static final String IS_TRANSLATION_OF = "isTranslationOf";


	protected static final String IS_EXPOSED_AS = "isExposedAs";


	protected static final String IS_CANDIDATE = "isCandidate";


	protected static final String IS_TRANSCRIPT_OF = "isTranscriptOf";


	protected static final String HAS_NATIVE_CONTENT = "hasNativeContent";


	protected static final String IS_LOCATED_AT = "isLocatedAt";


	protected static final String HAS_CLUSTER_PROXIMITY = "hasClusterProximity";


	protected static final String IS_RECOGNITION_OF = "isRecognitionOf";


	protected static final String HAS_NORMALISED_CONTENT = "hasNormalisedContent";


	protected static final String IS_SHOT_OF = "isShotOf";


	protected static final String HAS_ORIGINAL_FILE_SIZE = "hasOriginalFileSize";


	protected static final String IS_DELIMITER_OF_SHOT_UNIT = "isDelimiterOfShotUnit";


	protected static final String IS_DELIMITER_OF_TRANSLATION_UNIT = "isDelimiterOfTranslationUnit";


	protected static final String IS_SUMMARY_OF = "isSummaryOf";


	protected static final String IS_GENERATED_FROM = "isGeneratedFrom";


	protected static final String IS_EXPOSED_AS_THUMBNAIL = "isExposedAsThumbnail";


	protected static final String CAN_BE_IGNORED = "canBeIgnored";


	protected static final String IS_SOUNDTRACK_OF = "isSoundtrackOf";


	protected static final String IS_CLEANSING_OF = "isCleansingOf";


	protected static final String IS_DELIMITER_OF_CLEANSING_UNIT = "isDelimiterOfCleansingUnit";


	protected static final String HAS_GATHERING_DATE = "hasGatheringDate";


	protected static final String IS_DELIMITER_OF_SYNTHESIS_UNIT = "isDelimiterOfSynthesisUnit";


	/**
	 * WProcessingAnnotator constructor on a PieceOfKnowledge using given URI as the default subject.
	 */
	public WProcessingAnnotator(final URI subject, final PieceOfKnowledge pieceOfKnowledge) {
		super(subject, pieceOfKnowledge);
	}


	/**
	 * WProcessingAnnotator constructor on a resource.
	 */
	public WProcessingAnnotator(final Resource resource) {
		super(resource);
	}


	/**
	 * Read the Links a synthesized Audio unit to its source Text.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readSynthesisOf() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_SYNTHESIS_OF, URI.class, null);
	}


	/**
	 * Write the Links a synthesized Audio unit to its source Text.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeSynthesisOf(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_SYNTHESIS_OF, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the summary MediaUnit it represents.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readDelimiterOfSummaryUnit() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_SUMMARY_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the summary MediaUnit it represents.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeDelimiterOfSummaryUnit(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_SUMMARY_UNIT,
				URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the transcript MediaUnit it represents.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readDelimiterOfTranscriptUnit() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_TRANSCRIPT_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the transcript MediaUnit it represents.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeDelimiterOfTranscriptUnit(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI,
				WProcessingAnnotator.IS_DELIMITER_OF_TRANSCRIPT_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a frame Image to its source Video.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readFrameOf() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_FRAME_OF, URI.class, null);
	}


	/**
	 * Write the Links a frame Image to its source Video.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeFrameOf(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_FRAME_OF, URI.class, value)
				.getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the recognition MediaUnit it represents.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readDelimiterOfRecognitionUnit() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_RECOGNITION_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the recognition MediaUnit it represents.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeDelimiterOfRecognitionUnit(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI,
				WProcessingAnnotator.IS_DELIMITER_OF_RECOGNITION_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the frame MediaUnit it represents.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readDelimiterOfFrameUnit() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_FRAME_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the frame MediaUnit it represents.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeDelimiterOfFrameUnit(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_FRAME_UNIT,
				URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Indicates the service that has produced automatically or semi-automatically the resource.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readProducedBy() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_PRODUCED_BY, URI.class, null);
	}


	/**
	 * Write the Indicates the service that has produced automatically or semi-automatically the resource.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeProducedBy(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_PRODUCED_BY, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the MediaUnit it represents.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readDelimiterOf() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF, URI.class, null);
	}


	/**
	 * Write the Links a segment to the MediaUnit it represents.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeDelimiterOf(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a resource to the service that has modified this resource.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readBeenUpdatedBy() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_BEEN_UPDATED_BY, URI.class, null);
	}


	/**
	 * Write the Links a resource to the service that has modified this resource.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeBeenUpdatedBy(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_BEEN_UPDATED_BY, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a WebLab Document to a Cluster.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readInCluster() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_IN_CLUSTER, URI.class, null);
	}


	/**
	 * Write the Links a WebLab Document to a Cluster.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeInCluster(final URI value) {
		return this
				.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_IN_CLUSTER, URI.class, value)
				.getIsAnnotatedOn();
	}


	/**
	 * Read the Link a ClusterLink with its two components clusters.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readComposedByCluster() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_COMPOSED_BY_CLUSTER, URI.class, null);
	}


	/**
	 * Write the Link a ClusterLink with its two components clusters.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeComposedByCluster(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_COMPOSED_BY_CLUSTER,
				URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a cluster to a ClusterLink.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readInClusterLink() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_IN_CLUSTER_LINK, URI.class, null);
	}


	/**
	 * Write the Links a cluster to a ClusterLink.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeInClusterLink(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_IN_CLUSTER_LINK, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to an instance of a recognised entity (given its URI).
	 * 
	 * @return an URI
	 */
	public final Value<URI> readRefersTo() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.REFERS_TO, URI.class, null);
	}


	/**
	 * Write the Links a segment to an instance of a recognised entity (given its URI).
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeRefersTo(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.REFERS_TO, URI.class, value)
				.getIsAnnotatedOn();
	}


	/**
	 * Read the Gives the name of the original file gathered.
	 * 
	 * @return a String
	 */
	public final Value<String> readOriginalFileName() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_ORIGINAL_FILE_NAME, String.class, null);
	}


	/**
	 * Write the Gives the name of the original file gathered.
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeOriginalFileName(final String value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_ORIGINAL_FILE_NAME,
				String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the soundtrack MediaUnit it represents.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readDelimiterOfSoundtrackUnit() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_SOUNDTRACK_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the soundtrack MediaUnit it represents.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeDelimiterOfSoundtrackUnit(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI,
				WProcessingAnnotator.IS_DELIMITER_OF_SOUNDTRACK_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links translated Text or LinearSegment to its source Text or LinearSegment.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readTranslationOf() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_TRANSLATION_OF, URI.class, null);
	}


	/**
	 * Write the Links translated Text or LinearSegment to its source Text or LinearSegment.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeTranslationOf(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_TRANSLATION_OF, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Is exposed on a given protocol at a given address (for instance points to an URL).
	 * 
	 * @return a String
	 */
	public final Value<String> readExposedAs() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_EXPOSED_AS, String.class, null);
	}


	/**
	 * Write the Is exposed on a given protocol at a given address (for instance points to an URL).
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeExposedAs(final String value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_EXPOSED_AS, String.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Indicates whether or not is the instance extracted a candidate instance.
	 * 
	 * @return a Boolean
	 */
	public final Value<Boolean> readCandidate() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_CANDIDATE, Boolean.class, null);
	}


	/**
	 * Write the Indicates whether or not is the instance extracted a candidate instance.
	 * 
	 * @param value
	 *            a Boolean
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeCandidate(final Boolean value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_CANDIDATE, Boolean.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a transcript to its source (Image or Video MediaUnit).
	 * 
	 * @return an URI
	 */
	public final Value<URI> readTranscriptOf() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_TRANSCRIPT_OF, URI.class, null);
	}


	/**
	 * Write the Links a transcript to its source (Image or Video MediaUnit).
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeTranscriptOf(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_TRANSCRIPT_OF, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a media unit to its native content.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readNativeContent() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_NATIVE_CONTENT, URI.class, null);
	}


	/**
	 * Write the Links a media unit to its native content.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeNativeContent(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_NATIVE_CONTENT, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a MediaUnit to the segment from which it has been produced.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readLocatedAt() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_LOCATED_AT, URI.class, null);
	}


	/**
	 * Write the Links a MediaUnit to the segment from which it has been produced.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeLocatedAt(final URI value) {
		return this
				.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_LOCATED_AT, URI.class, value)
				.getIsAnnotatedOn();
	}


	/**
	 * Read the Value that corresponds to the proximity between the two clusters implied in a cluster link.
	 * 
	 * @return a Double
	 */
	public final Value<Double> readClusterProximity() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_CLUSTER_PROXIMITY, Double.class, null);
	}


	/**
	 * Write the Value that corresponds to the proximity between the two clusters implied in a cluster link.
	 * 
	 * @param value
	 *            a Double
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeClusterProximity(final Double value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_CLUSTER_PROXIMITY,
				Double.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links an extracted Text to its source Image.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readRecognitionOf() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_RECOGNITION_OF, URI.class, null);
	}


	/**
	 * Write the Links an extracted Text to its source Image.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeRecognitionOf(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_RECOGNITION_OF, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a media unit to its normalised content.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readNormalisedContent() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_NORMALISED_CONTENT, URI.class, null);
	}


	/**
	 * Write the Links a media unit to its normalised content.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeNormalisedContent(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_NORMALISED_CONTENT,
				URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a shot Video to its source Video.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readShotOf() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_SHOT_OF, URI.class, null);
	}


	/**
	 * Write the Links a shot Video to its source Video.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeShotOf(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_SHOT_OF, URI.class, value)
				.getIsAnnotatedOn();
	}


	/**
	 * Read the Gives the number of bytes of the original file gathered.
	 * 
	 * @return a Long
	 */
	public final Value<Long> readOriginalFileSize() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_ORIGINAL_FILE_SIZE, Long.class, null);
	}


	/**
	 * Write the Gives the number of bytes of the original file gathered.
	 * 
	 * @param value
	 *            a Long
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeOriginalFileSize(final Long value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_ORIGINAL_FILE_SIZE,
				Long.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the shot MediaUnit it represents.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readDelimiterOfShotUnit() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_SHOT_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the shot MediaUnit it represents.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeDelimiterOfShotUnit(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_SHOT_UNIT,
				URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the translation MediaUnit it represents.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readDelimiterOfTranslationUnit() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_TRANSLATION_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the translation MediaUnit it represents.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeDelimiterOfTranslationUnit(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI,
				WProcessingAnnotator.IS_DELIMITER_OF_TRANSLATION_UNIT, URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a summary to its source Text.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readSummaryOf() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_SUMMARY_OF, URI.class, null);
	}


	/**
	 * Write the Links a summary to its source Text.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeSummaryOf(final URI value) {
		return this
				.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_SUMMARY_OF, URI.class, value)
				.getIsAnnotatedOn();
	}


	/**
	 * Read the Links a resource or segment result of an automatic (translation, summarisation, transcription) process to its source resource or segment.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readGeneratedFrom() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_GENERATED_FROM, URI.class, null);
	}


	/**
	 * Write the Links a resource or segment result of an automatic (translation, summarisation, transcription) process to its source resource or segment.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeGeneratedFrom(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_GENERATED_FROM, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Is exposed as a given thumbnail at a given address (for instance points to an URL).
	 * 
	 * @return a String
	 */
	public final Value<String> readExposedAsThumbnail() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_EXPOSED_AS_THUMBNAIL, String.class, null);
	}


	/**
	 * Write the Is exposed as a given thumbnail at a given address (for instance points to an URL).
	 * 
	 * @param value
	 *            a String
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeExposedAsThumbnail(final String value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_EXPOSED_AS_THUMBNAIL,
				String.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Indicates whether or not a MediaUnit can be ignored by a service.
	 * 
	 * @return a Boolean
	 */
	public final Value<Boolean> readCanBeIgnored() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.CAN_BE_IGNORED, Boolean.class, null);
	}


	/**
	 * Write the Indicates whether or not a MediaUnit can be ignored by a service.
	 * 
	 * @param value
	 *            a Boolean
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeCanBeIgnored(final Boolean value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.CAN_BE_IGNORED, Boolean.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a soundtrack to its source Video.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readSoundtrackOf() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_SOUNDTRACK_OF, URI.class, null);
	}


	/**
	 * Write the Links a soundtrack to its source Video.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeSoundtrackOf(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_SOUNDTRACK_OF, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a cleansed MediaUnit to its source MediaUnit.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readCleansingOf() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_CLEANSING_OF, URI.class, null);
	}


	/**
	 * Write the Links a cleansed MediaUnit to its source MediaUnit.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeCleansingOf(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_CLEANSING_OF, URI.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the cleansing MediaUnit it represents.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readDelimiterOfCleansingUnit() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_CLEANSING_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the cleansing MediaUnit it represents.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeDelimiterOfCleansingUnit(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_CLEANSING_UNIT,
				URI.class, value).getIsAnnotatedOn();
	}


	/**
	 * Read the Gives the date when the Document was gathered.
	 * 
	 * @return a Date
	 */
	public final Value<Date> readGatheringDate() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_GATHERING_DATE, Date.class, null);
	}


	/**
	 * Write the Gives the date when the Document was gathered.
	 * 
	 * @param value
	 *            a Date
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeGatheringDate(final Date value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.HAS_GATHERING_DATE, Date.class,
				value).getIsAnnotatedOn();
	}


	/**
	 * Read the Links a segment to the synthesis MediaUnit it represents.
	 * 
	 * @return an URI
	 */
	public final Value<URI> readDelimiterOfSynthesisUnit() {
		return this.applyOperator(Operator.READ, null, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_SYNTHESIS_UNIT, URI.class, null);
	}


	/**
	 * Write the Links a segment to the synthesis MediaUnit it represents.
	 * 
	 * @param value
	 *            an URI
	 * @return a PieceOfKnowledge
	 */
	public final PieceOfKnowledge writeDelimiterOfSynthesisUnit(final URI value) {
		return this.applyOperator(Operator.WRITE, WProcessingAnnotator.APREFIX, WProcessingAnnotator.AURI, WProcessingAnnotator.IS_DELIMITER_OF_SYNTHESIS_UNIT,
				URI.class, value).getIsAnnotatedOn();
	}



}
