package org.ow2.weblab.rdf;

/**
 * A parser to transform String into an Object whose type it <T>
 * @author asaval
 *
 * @param <T> the tpe supported by the parser 
 */
public abstract class AbstractTypeParser<T> {

	/**
	 * Parse a String containing data to and Object of the required type.
	 * @param value a String containing data (can be null)
	 * @return an Object that is a representation of the value in the type T 
	 */
	public abstract T parse(String value);
	
	/**
	 * Override this method to return a default value on an exception occurring during parse.
	 * By default, returns null.
	 * @param e the thrown exception
	 * @return the default value when parse(String) throws an exception
	 */
	public T defaultValueOnException(Exception exception){
		return null;
	}
	
}
