/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2012 CASSIDIAN, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.annotator;

import java.net.URI;
import java.util.Date;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.stream.XMLStreamException;

import junit.framework.Assert;

import org.junit.Test;
import org.ow2.weblab.core.extended.factory.WebLabResourceFactory;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.processing.WProcessingAnnotator;
import org.ow2.weblab.rdf.RDFWriter;

public class DateTimeSupport {


	@Test
	public void testISO8601support() throws XMLStreamException, ParserConfigurationException {
		final String day = "2011-06-29";
		// String separateDateAndTimeUTC = "2011-06-29 05:43Z";
		final String combineDateAndTimeUTC = "2011-06-29T05:43Z";
		final String dateWithWeekNumber = "2011-W26-3";
		final String ordinalDate = "2011-180";

		final String[] datesToTest = new String[] { day,
				// separateDateAndTimeUTC,
				combineDateAndTimeUTC, dateWithWeekNumber, ordinalDate };

		for (final String date : datesToTest) {

			final PieceOfKnowledge pok = WebLabResourceFactory.createResource("pok", "res", PieceOfKnowledge.class);
			final URI pokURI = URI.create(pok.getUri());

			RDFWriter.writeStatement(pok, pokURI, "wp", URI.create("http://weblab.ow2.org/core/1.2/ontology/processing#"), "hasGatheringDate", date, null,
					true, Element.getDefaultElement());

			final WProcessingAnnotator wpa = new WProcessingAnnotator(pokURI, pok);

			final Date d = wpa.readGatheringDate().firstTypedValue();
			Assert.assertNotNull(d);
		}

	}
}
