/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper.impl.parser;

/**
 * Abstract class to create Type Parser from String
 * @author asaval
 *
 * @param <T> the type
 */
public abstract class TypeParser<T> {


	/**
	 * Parses an Object into a Type  
	 * @param object an object
	 * @return an instance of a <T> class
	 */
	public T parseValue(final Object object) {
		if (!Parsers.strict || ((object instanceof String) && this.matches(object.toString()))) {
			final String[] values = this.split(object.toString());
			return this.parseTypeValue(values[0], values[1], values[2]);
		}
		return null;
	}

	/**
	 * Do the real parsing of the value   
	 * @param value the value
	 * @param type the type of the value
	 * @param lang the language of the value
	 * @return an instance of a <T> class
	 */
	protected abstract T parseTypeValue(String value, String type, String lang);


	/**
	 * Checks if the given value matches parser rules.
	 * @param value the value
	 * @return true if the value matches the parser rules else false.
	 */
	protected abstract boolean matches(String value);


	/**
	 * Split a Literal String into its components
	 * @param literal the string
	 * @return an array of the value, the type and the language if defined representing the literal
	 */
	protected String[] split(final String literal) {
		final int index = literal.lastIndexOf('"');
		final int atIndex = literal.indexOf('@', index);
		String lang = "";
		String type = "";
		String value = literal;
		if (literal.startsWith("\"") && (index > 0)) {
			value = literal.substring(1, index);
			final String tstring = literal.substring(index);
			int separator = tstring.indexOf("^^");
			separator = index + ((separator == -1) ? 1 : separator + 2);
			if (atIndex != -1) {
				lang = literal.substring(atIndex + 1);
				type = literal.substring(separator, atIndex);
			} else {
				type = literal.substring(separator);
			}
		}
		return new String[] { value, type, lang };
	}

}
