/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl;

import junit.framework.Assert;

import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.helper.impl.Rule.Domain;
import org.ow2.weblab.core.helper.test.ResourcesCreator;
import org.ow2.weblab.core.model.Document;

import com.hp.hpl.jena.graph.DNode;
import com.hp.hpl.jena.graph.Node;
import com.hp.hpl.jena.graph.Triple;

public class FilterTest {


	@BeforeClass
	public static void buildResources() throws WebLabCheckedException {
		if (!ResourcesCreator.DOCUMENT.exists()) {
			ResourcesCreator.buildTestResources();
		}
	}


	@Test
	public void testFilter() throws WebLabCheckedException {
		final Filter filterPO = new Filter();
		final Filter filterSP = new Filter();
		final Filter filterSO = new Filter();
		filterPO.addPOFilter(RDF.TYPE, null);
		filterSP.addSPFilter(null, RDF.TYPE);
		filterSO.addSOFilter(null, "null");

		final Document doc = new WebLabMarshaller().unmarshal(ResourcesCreator.DOCUMENT, Document.class);

		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);

		rs.findInResource(doc, filterPO);
		rs.findInResource(doc, filterSP);
		rs.findInResource(doc, filterSO);
		
		
	}


	@Test
	public void testRules() {
		try {
			Rule.Domain.valueOf("test");
			Assert.fail();
		} catch (final IllegalArgumentException e) {
			// An exception should have been thrown
		}
		Assert.assertEquals(Domain.SUBJECT, Rule.Domain.valueOf("" + Domain.SUBJECT));

		final Rule rule1 = new Rule(Domain.OBJECT, "empty", Domain.SUBJECT, "empty");
		final Rule rule2 = new Rule(Domain.OBJECT, "empty", null, null);
		final Filter filter = new Filter();
		filter.rules.add(rule1);
		Assert.assertTrue(filter.matches(new WTriple("empty", "test", "empty", null, null, null)));
		final Filter filter2 = new Filter();
		filter2.rules.add(rule2);
		Assert.assertTrue(filter2.matches(new WTriple("empty", "test", "empty", null, null, null)));
		Assert.assertTrue(filter2.matches(rule2, new Triple(Node.createURI("empty"), Node.createURI("test"), Node.createURI("empty"))));
		
		Assert.assertFalse(filter2.matches(new Rule(Domain.PREDICATE, null, Domain.SUBJECT, null), new Triple(Node.ANY,new DNode(){
			public String toString(){
				return null;
			}
		},Node.ANY)));
	}

}
