/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl;

import java.io.File;
import java.util.List;

import junit.framework.Assert;

import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.extended.ontologies.WebLabProcessing;
import org.ow2.weblab.core.helper.test.ResourcesCreator;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.ComposedResource;
import org.ow2.weblab.core.model.Document;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.core.model.ResultSet;


public class SelectorTest {


	@BeforeClass
	public static void buildResources() throws WebLabCheckedException {
		if (!ResourcesCreator.DOCUMENT.exists() ||
			!ResourcesCreator.COMPOSED_RESOURCE2.exists() ||
			!ResourcesCreator.COMPOSED_RESOURCE.exists()  ||
			!ResourcesCreator.RESULT_SET.exists()  ||
			!ResourcesCreator.COMPOSED_RESOURCE.exists()  ||
			!ResourcesCreator.ANNOTATION.exists()) {
			ResourcesCreator.buildTestResources();
		}
	}


	@Test
	public void testAnnots() throws WebLabCheckedException {
		buildResources();
		final AdvancedSelector as = RDFSelectorFactory.getSelector(true,"uname");
		final Annotation doc = new WebLabMarshaller().unmarshal(ResourcesCreator.ANNOTATION, Annotation.class);
		// SelectAll
		final List<WTriple> list = as.findInResource(doc, null, null, "uname:tester");
		Assert.assertFalse(list.isEmpty());
	}


	@Test
	public void testFilterAnnots() throws WebLabCheckedException {
		buildResources();
		final AdvancedSelector as = RDFSelectorFactory.getSelector(true);
		final Filter f = new Filter();
		f.addPOFilter(".*", "empty5");

		final Document doc = new WebLabMarshaller().unmarshal(ResourcesCreator.DOCUMENT, Document.class);
		// SelectAll
		final List<WTriple> list = as.findInResource(doc, f);
		Assert.assertFalse(list.isEmpty());
	}


	@Test
	public void testStanag() throws WebLabCheckedException {
		buildResources();
		final AdvancedSelector as = RDFSelectorFactory.getSelector(true);
		final Filter f = new Filter();
		f.addPOFilter(".*type.*", ".*");

		Document doc = new WebLabMarshaller().unmarshal(new File("./target/res_1.xml"), Document.class);

		final List<WTriple> list = as.findInResource(doc, f);
		Assert.assertFalse(list.isEmpty());
	}


	/**
	 * Rebuild entities from RDF
	 */
	@Test
	public void testWTripleMap() throws WebLabCheckedException {
		buildResources();
		final AdvancedSelector as = RDFSelectorFactory.getSelector(true);
		final ComposedResource doc = new WebLabMarshaller().unmarshal(ResourcesCreator.COMPOSED_RESOURCE, ComposedResource.class);
		final Statements map = as.searchFor(doc, RDF.TYPE, RDFS.LABEL);
		Assert.assertFalse(map.isEmpty());
	}


	/**
	 * Test for a list of values support
	 */
	@Test
	public void testMultiResult() throws WebLabCheckedException {
		buildResources();
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		final ResultSet rc = new WebLabMarshaller().unmarshal(ResourcesCreator.RESULT_SET, ResultSet.class);
		final Statements wtm = rs.searchFor(rc);
		Assert.assertFalse(wtm.isEmpty());
	}


	@Test
	public void testSearchResult() throws WebLabCheckedException {
		buildResources();
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		final ComposedResource rc = new WebLabMarshaller().unmarshal(ResourcesCreator.COMPOSED_RESOURCE, ComposedResource.class);
		final Statements wtm = rs.searchFor(rc, WebLabProcessing.HAS_GATHERING_DATE);
		Assert.assertFalse(wtm.isEmpty());
	}


	@Test
	public void testSearchResult2() throws WebLabCheckedException {
		buildResources();
		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		final ComposedResource rc = new WebLabMarshaller().unmarshal(ResourcesCreator.COMPOSED_RESOURCE, ComposedResource.class);
		final String[] preds = new String[] { "http://weblab-project.org/core/model/1.0/property/extracted/concept/visual",
				"http://purl.org/dc/elements/1.1/title", "http://purl.org/dc/elements/1.1/creator", "http://purl.org/dc/elements/1.1/subject",
				"http://purl.org/dc/elements/1.1/description", "http://purl.org/dc/elements/1.1/date", "http://purl.org/dc/elements/1.1/language",
				"http://purl.org/dc/elements/1.1/publisher", "http://purl.org/dc/elements/1.1/contibutor", "http://purl.org/dc/elements/1.1/type",
				"http://purl.org/dc/elements/1.1/format", "http://purl.org/dc/elements/1.1/identifier", "http://purl.org/dc/elements/1.1/source",
				"http://purl.org/dc/elements/1.1/relation", "http://purl.org/dc/elements/1.1/coverage", "http://purl.org/dc/elements/1.1/right",
				"http://weblab-project.org/core/model/1.0/property/hasNativeContent", "http://weblab-project.org/core/model/1.0/property/hasNormalisedContent",
				"http://weblab-project.org/core/model/1.0/property/isGeneratedFrom", "http://weblab-project.org/core/model/1.0/property/isProducedFrom",
				"http://weblab-project.org/core/model/1.0/property/isResultOf", "http://weblab-project.org/core/model/1.0/property/hasHitScore",
				"http://weblab-project.org/core/model/1.0/property/hasNumberOfResults", "http://weblab-project.org/core/model/1.0/property/isExposedAs",
				"http://purl.org/dc/terms/extent", "http://purl.org/dc/terms/modified", "http://purl.org/dc/terms/created",
				"http://weblab-project.org/core/model/1.0/property/hasCrawlingDate", RDFS.LABEL};

		final Statements wtm = rs.searchFor(rc, preds);
		Assert.assertFalse(wtm.isEmpty());
		
	}


	@Test
	public void testFilter() throws WebLabCheckedException {
		buildResources();
		final String GEONAMES = "http://www.geonames.org/ontology/Feature";
		final Filter filter = new Filter();
		filter.addPOFilter(RDF.TYPE, "http://www.weblab-project.org/ontologies/stanag2433.owl#Event");
		filter.addPOFilter("http://www.weblab-project.org/ontologies/stanag2433.owl#e-eLoc_geographicLocationData", ".*");
		filter.addPOFilter(GEONAMES, ".*");
		filter.addPOFilter(WebLabProcessing.REFERS_TO, ".*");
		filter.addPOFilter(RDFS.LABEL, ".*");
		filter.addPOFilter("http://www.opengis.net/gml/_Feature/Latitude", ".*");
		filter.addPOFilter("http://www.opengis.net/gml/_Feature/Longitude", ".*");

		final Document doc = new WebLabMarshaller().unmarshal(ResourcesCreator.DOCUMENT, Document.class);

		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		final List<WTriple> wl = rs.findInResource(doc, filter);
		
		Assert.assertFalse(wl.isEmpty());

	}


	@Test
	public void testNotReif() throws WebLabCheckedException {
		buildResources();
		final Document doc = new WebLabMarshaller().unmarshal(ResourcesCreator.DOCUMENT, Document.class);

		final AdvancedSelector rs = RDFSelectorFactory.getSelector(true);
		final List<WTriple> wl1 = rs.findInResource(doc, null, RDF.TYPE, null, false);
		final List<WTriple> wl2 = rs.findInResource(doc, null, RDF.TYPE, null, true);
		Assert.assertFalse(wl1.isEmpty());
		Assert.assertFalse(wl2.isEmpty());
	}


	@Test
	public void testNullData() {
		final Resource r = new Resource();
		// Segment s = new Segment(){};
		final Annotation a = new Annotation();
		r.getAnnotation().add(a);

		final TripleSelectors ts = new TripleSelectors(true);
		List<WTriple> list = ts.findInResource(r, null, null, null);
		Assert.assertTrue(list.isEmpty());
	}


	private Document loadDoc() throws WebLabCheckedException {
		buildResources();
		return new WebLabMarshaller().unmarshal(ResourcesCreator.DOCUMENT, Document.class);
	}


	@Test
	public void testConcatSelection() throws WebLabCheckedException {
		buildResources();
		AdvancedSelector as = RDFSelectorFactory.getSelector(true);
		final Document doc = this.loadDoc();
		List<WTriple> list = as.findInResource(doc, null, RDF.TYPE, null);
		Assert.assertFalse(list.isEmpty());
		
		as = RDFSelectorFactory.getSelector(true);
		final List<WTriple> l = as.findInResource(doc, null, RDF.TYPE, null);
		Assert.assertFalse(l.isEmpty());
		
	}

	@Test
	public void testTripleSelector() throws WebLabCheckedException {
		buildResources();
		ComplexTripleSelector cts = new ComplexTripleSelector();
		final Document doc = this.loadDoc();
		Statements sts = cts.searchFor(doc);
		Assert.assertEquals(2, sts.size());
		
		TripleSelectors ts = new TripleSelectors(true);
		List<WTriple> triples = ts.findInResource(doc, null, null, null);
		Assert.assertEquals(47, triples.size());
	}
	
	@Test
	public void testMTSelector() throws WebLabCheckedException {
		buildResources();
		TripleSelectors.multi = true; 
		final Document doc = this.loadDoc();
		TripleSelectors ts = new TripleSelectors(true);
		List<WTriple> triples = ts.findInResource(doc, null, null, null);
		Assert.assertEquals(47, triples.size());
		
		ts = new TripleSelectors(true, (String[])null);
		triples = ts.findInResource(doc, null, null, null);
		Assert.assertEquals(47, triples.size());
		
	}
}
