/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.impl.parser;

import java.lang.reflect.Field;
import java.lang.reflect.Method;

import org.apache.commons.logging.LogFactory;

public class ReflectChanger {


	public static void setSystemClassLoader(final ClassLoader cl) throws SecurityException, IllegalArgumentException {
		ReflectChanger.setField(null, ClassLoader.class, "scl", cl, true);
	}


	public static <T> void setField(final T object, final Class<? extends T> clazz, final String fieldName, final Object value, final boolean declared) {
		Field f;
		try {
			f = declared ? clazz.getDeclaredField(fieldName) : clazz.getField(fieldName);
			f.setAccessible(true);
			f.set(object, value);
		} catch (final Exception e) {
			LogFactory.getLog(ReflectChanger.class).info("An error occured but we don't care...", e);
		}

	}


	public static <T> Object invoke(final T object, final Class<? extends T> clazz, final String methodName, final boolean declared, final Object[] args,
			final Class<?>... params) {
		try {
			final Method m = declared ? clazz.getDeclaredMethod(methodName, params) : clazz.getMethod(methodName, params);
			m.setAccessible(true);
			final Object result = m.invoke(object, args);
			return result;
		} catch (final Exception e) {
			LogFactory.getLog(ReflectChanger.class).info("An error occured but we don't care...", e);
		}
		return null;
	}

}
