/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.test;

import java.io.File;
import java.util.List;

import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDF;
import org.ow2.weblab.core.extended.ontologies.WebLabRetrieval;
import org.ow2.weblab.core.helper.impl.AdvancedSelector;
import org.ow2.weblab.core.helper.impl.RDFSelectorFactory;
import org.ow2.weblab.core.helper.impl.Results;
import org.ow2.weblab.core.helper.impl.SimpleSelector;
import org.ow2.weblab.core.helper.impl.Statements;
import org.ow2.weblab.core.helper.impl.WTriple;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.ComposedResource;
import org.ow2.weblab.core.model.ResultSet;


public class BugTester {


	@BeforeClass
	public static void buildResources() throws WebLabCheckedException {
		if (!ResourcesCreator.ANNOTATION.exists()) {
			ResourcesCreator.buildTestResources();
		}
	}


	@Test
	public void totest2() throws WebLabCheckedException {
		final ResultSet resultSet = new WebLabMarshaller().unmarshal(ResourcesCreator.RESULT_SET, ResultSet.class);
		final SimpleSelector simpleSelector = RDFSelectorFactory.getSelector();
		final Results results = simpleSelector.select(resultSet.getPok());
		for (final String hitUri : results.getSubjects(RDF.TYPE, WebLabRetrieval.HIT)) {
			Assert.assertFalse(results.get(hitUri).isEmpty());
		}
		
	}

	@Test
	public void totest1() throws WebLabCheckedException {
		final ComposedResource resource = new WebLabMarshaller().unmarshal(new File("./target/composedResource2.xml"), ComposedResource.class);
		final Annotation annotation = new Annotation();

		final AdvancedSelector selector = RDFSelectorFactory.getSelector(true);
		final Statements s = selector.searchFor(resource);
		selector.searchFor(annotation, "weblab://property/test");
		final List<WTriple> lw = selector.findInResource(resource, null, null, null, true);
		Assert.assertFalse(s.isEmpty());
		Assert.assertFalse(lw.isEmpty());
	}

}
