/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.test;

import java.util.Locale;

import junit.framework.Assert;

import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.extended.ontologies.RDFS;
import org.ow2.weblab.core.helper.impl.AdvancedSelector;
import org.ow2.weblab.core.helper.impl.RDFSelectorFactory;
import org.ow2.weblab.core.helper.impl.Statements;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.ResultSet;

public class LangTest {


	@BeforeClass
	public static void buildResources() throws WebLabCheckedException {
		if (!ResourcesCreator.ANNOTATION.exists()) {
			ResourcesCreator.buildTestResources();
		}
	}


	@Test
	public void testLangRDFSpec() throws WebLabCheckedException {
		final Annotation a = new WebLabMarshaller().unmarshal(ResourcesCreator.ANNOTATION, Annotation.class);

		final AdvancedSelector rdfs = RDFSelectorFactory.getSelector(true);
		final Statements m = rdfs.searchFor(a);
		// m.getFirstValue(subject,predicat,Locale.CANADA_FRENCH.)
		Assert.assertEquals("empty", m.getFirstValue(null, RDFS.LABEL, Locale.FRENCH));
		Assert.assertTrue(m.getFirstValue(null, RDFS.LABEL, null) != null);
	}


	@Test
	public void testLangBuggyRS() throws WebLabCheckedException {
		final ResultSet a = new WebLabMarshaller().unmarshal(ResourcesCreator.RESULT_SET, ResultSet.class);

		final AdvancedSelector rdfs = RDFSelectorFactory.getSelector(true);
		final Statements m = rdfs.searchFor(a);
		Assert.assertNull(m.getFirstValue(null, RDFS.LABEL, Locale.ENGLISH));
	}

}
