/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 *  
 * Copyright (C) 2004 - 2012 Cassidian, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
package org.ow2.weblab.core.helper.test;

import java.io.File;
import java.util.Set;

import junit.framework.Assert;

import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.weblab.core.extended.exception.WebLabCheckedException;
import org.ow2.weblab.core.extended.jaxb.WebLabMarshaller;
import org.ow2.weblab.core.helper.impl.AdvancedSelector;
import org.ow2.weblab.core.helper.impl.ComplexTripleSelector;
import org.ow2.weblab.core.helper.impl.RDFSelectorFactory;
import org.ow2.weblab.core.helper.impl.Statements;
import org.ow2.weblab.core.helper.impl.parser.RDFTransparentStringTypeParser;
import org.ow2.weblab.core.model.Document;


public class ParseDocument {


	@BeforeClass
	public static void buildResources() throws WebLabCheckedException {
		if (!ResourcesCreator.DOCUMENT.exists()) {
			ResourcesCreator.buildTestResources();
		}
	}


	@Test
	public void testGetSubjects() throws WebLabCheckedException {
		final Document resource = new WebLabMarshaller().unmarshal(new File("./target/res_1.xml"), Document.class);
		final AdvancedSelector as = RDFSelectorFactory.getSelector(true);
		final Statements sts = as.searchFor(resource);
		final Set<String> res = sts.getSubjects(null, "http://sws.geonames.org/630673/");
		Assert.assertTrue(res.contains("http://www.virtuoso.eu/ontology/instances/Location#black_sea"));
		Assert.assertTrue(res.contains("itm:n#_101339"));
	}


	@Test
	public void testDoc() throws WebLabCheckedException {
		final Document doc = new WebLabMarshaller().unmarshal(ResourcesCreator.DOCUMENT, Document.class);
		final ComplexTripleSelector rrs = new ComplexTripleSelector(true, "http://www.weblab-project.org/ontologies/stanag2433.owl");
		rrs.addPORule("http://www.w3.org/1999/02/22-rdf-syntax-ns#type", "http://www.weblab-project.org/ontologies/stanag2433.owl#Event");
		rrs.addPORule("http://www.opengis.net/gml/_Feature/Latitude", ".*");
		rrs.addPORule("http://www.opengis.net/gml/_Feature/Longitude", ".*");
		rrs.addPORule("http://www.w3.org/2000/01/rdf-schema#label", ".*");
		final Statements wm = new Statements();
		wm.addAll(rrs.findIn(doc));
	}


	@Test
	public void testStringParsing() {
		final RDFTransparentStringTypeParser sp = new RDFTransparentStringTypeParser();
		Assert.assertEquals("my @ value", sp.parseValue("\"my @ value\""));
		Assert.assertEquals("my @ value", sp.parseValue("\"my @ value\"@fr"));
	}

}
