/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2012 CASSIDIAN, an EADS company
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.core.helper.impl;

import org.ow2.weblab.core.extended.util.PoKUtil;
import org.ow2.weblab.core.model.Annotation;
import org.ow2.weblab.core.model.Resource;

/**
 * This is the simplest implementation of the <code>ResourceHelper</code>. It only loads every <code>Annotations</code> that are on this object. No
 * crawling of the <code>Resource</code>. Note that if the loaded <code>Resource</code> is itself a <code>PieceOfKnowledge</code>, its content won't be loaded.
 * 
 * @see ResourceHelper
 * @see JenaResourceHelper
 * @author EADS WebLab Team
 * @date 2008-11-25
 */
public class JenaSingleResourceHelper extends JenaResourceHelper {


	/**
	 * @param res
	 *            The Resource to load inside this helper.
	 */
	public JenaSingleResourceHelper(final Resource res) {
		super(res);
	}


	@Override
	protected void addResource(final Resource res) {
		for (final Annotation a : res.getAnnotation()) {
			final String rdf = PoKUtil.getPoKData(a);
			if (!rdf.trim().isEmpty()) {
				this.loadFromRdfXml(rdf, true);
			}
		}
	}

}
